@@ -9,7 +9,7 @@ from gunicorn.pidfile import Pidfile
 
 from dimensigon import defaults
 from dimensigon.exceptions import DimensigonError
-from dimensigon.use_cases.base import default_signal_handler, init_signals, TerminateInterrupt
+from dimensigon.use_cases.base import TerminateInterrupt
 from dimensigon.use_cases.catalog import CatalogManager
 from dimensigon.use_cases.cluster import ClusterManager
 from dimensigon.use_cases.file_sync import FileSync
@@ -55,20 +55,19 @@ class GunicornApp(Application):
 
 
 class Dimensigon:
-    MAX_TERMINATE_CALLED = 3
-    int_handler = staticmethod(default_signal_handler)
-    term_handler = staticmethod(default_signal_handler)
-    _logger = _logger
-
     def __init__(self):
         self.flask_app: t.Optional[DimensigonFlask] = None
         self.gunicorn: t.Optional[GunicornApp] = None
         self.server: t.Optional[mp.Process] = None
         self.config = Config(self)
-        self.manager = mp.Manager()
+
+        # processes
+        self.manager = mp.Manager()  # shared memory between processes
         self.cluster_manager: t.Optional[ClusterManager] = None
         self.file_sync: t.Optional[FileSync] = None
-        # self.log_sender: t.Optional[LogSender] = None  # log sender embedded in file_sync process
+        self.route_manager: t.Optional[RouteManager] = None
+        self.catalog_manager: t.Optional[CatalogManager] = None
+
         self.STOP_WAIT_SECS = 90
         self.engine = None  # set on setup_dm function
         self.get_session = None  # set on setup_dm function
@@ -87,6 +86,10 @@ class Dimensigon:
             self.gunicorn = GunicornApp(self.flask_app, self.config.http_conf)
             self.gunicorn.dm = self
 
+    def set_catalog_manager(self):
+        if self.catalog_manager is None:
+            self.catalog_manager = CatalogManager(None, None, None, None, None, self)
+
     def create_processes(self):
         self.cluster_manager = self._main_ctx.Proc(ClusterManager, self)
         self.cluster_manager.SHUTDOWN_WAIT_SECS = 90
@@ -130,6 +133,7 @@ class Dimensigon:
     def start(self):
         """starts dimensigon server"""
         _logger.info(f"Starting Dimensigon ({os.getpid()})")
+        self._main_ctx.init_signals()
         self.pid = os.getpid()
         pidname = self.config.pidfile
         self.pidfile = Pidfile(pidname)
@@ -152,10 +156,10 @@ class Dimensigon:
         _logger.info(f"Shutting down Dimensigon")
         self.http_server.terminate()
         self.http_server.terminate()
-        self._main_ctx.stop()
         self.http_server.join(90)
         if self.http_server.is_alive():
             self.http_server.kill()
+        self._main_ctx.stop()
 
 
 class Config:
@@ -208,4 +212,4 @@ class Config:
         """
         if self.config_dir is None:
             raise DimensigonError("config_dir is not set")
-        return os.path.join(self.config_dir, *path)
\ No newline at end of file
+        return os.path.join(self.config_dir, *path)
