@@ -1,4 +1,3 @@
-import datetime as dt
 import typing as t
 
 from dimensigon.utils.typos import Dill
@@ -77,12 +76,10 @@ class Parameter(db.Model):
             session = db.session
 
         if not session.query(cls).get('last_graceful_shutdown'):
-            p = Parameter('last_graceful_shutdown', dump=lambda x: x.strftime("%m/%d/%Y, %H:%M:%S.%f %z"),
-                          load=lambda x: dt.datetime.strptime(x, "%m/%d/%Y, %H:%M:%S.%f %z"))
+            p = Parameter('last_graceful_shutdown')
             session.add(p)
         if not session.query(cls).get('fetching_catalog'):
-            p = Parameter('fetching_catalog', dump=lambda x: '1' if x else '0',
-                          load=lambda x: True if x == '1' else False)
+            p = Parameter('fetching_catalog')
             session.add(p)
         if not session.query(cls).get('join_server'):
             p = Parameter('join_server')
