@@ -126,7 +126,7 @@ def server_routes(node, refresh=False):
         dprint(resp)
 
 
-def orch_list(ident=None, name=None, version=None, detail=False, like=None):
+def orch_list(ident=None, name=None, version=None, detail=False, like=None, schema=False):
     kwargs = {}
     view_data = dict()
     if ident is not None:
@@ -139,6 +139,8 @@ def orch_list(ident=None, name=None, version=None, detail=False, like=None):
         view_data.update({'params': ['steps', 'vars', 'target', 'action', 'human', 'split_lines']})
     else:
         view_data.update({'params': ['vars', 'target', 'human', 'split_lines']})
+    if schema:
+        view_data['params'].append('schema')
     resp = ntwrk.get('api_1_0.orchestrationlist', view_data=view_data, **kwargs)
     if resp.code == 200:
         data = resp.msg or []
@@ -208,7 +210,7 @@ def orch_load(file):
 
 def orch_run(orchestration_id, target, params=None, background=False, scope=None, skip_validation=False):
     data = {}
-    data.update(target=target, params=params, background=background)
+    data.update(hosts=target, params=params, background=background)
     if scope:
         data.update(scope=scope)
     if skip_validation:
@@ -464,7 +466,8 @@ def manager_catalog_refresh():
     dprint(resp)
 
 
-def manager_locker_ignore(ignore: bool, server_ids):
+def manager_locker_ignore(ignore: bool, nodes):
+    server_ids = [normalize2id(n) for n in nodes]
     resp = ntwrk.post('api_1_0.manager_server_ignore_lock', json={'server_ids': server_ids, 'ignore_on_lock': ignore})
     dprint(resp)
 
@@ -614,7 +617,10 @@ def vault_list_vars(scope='global'):
 
 def vault_read(variable, scope='global'):
     resp = ntwrk.get('api_1_0.vaultresource', dict(name=variable, scope=scope))
-    dprint(resp)
+    if resp.ok:
+        dprint(resp['value'])
+    else:
+        dprint(resp)
 
 
 def vault_write(variable, value, scope='global'):
@@ -622,8 +628,8 @@ def vault_write(variable, value, scope='global'):
     dprint(resp)
 
 
-def vault_delete(variable, value, scope='global'):
-    resp = ntwrk.delete('api_1_0.vaultresource', dict(name=variable, scope=scope), json={'value': value})
+def vault_delete(variable, scope='global'):
+    resp = ntwrk.delete('api_1_0.vaultresource', dict(name=variable, scope=scope))
     dprint(resp)
 
 
@@ -733,11 +739,11 @@ nested_dict = {
               login],
     "manager": {
         "catalog": {"refresh": [manager_catalog_refresh]},
-        "locker": {"ignore": [{'argument': 'server_ids', 'metavar': 'NODE', 'nargs': '+',
-                               'completer': server_completer},
+        "locker": {"ignore": [{'argument': 'nodes', 'metavar': 'NODE', 'nargs': '+',
+                               'completer': server_name_completer},
                               functools.partial(manager_locker_ignore, True)],
-                   "unignore": [{'argument': 'server_ids', 'metavar': 'NODE', 'nargs': '+',
-                                 'completer': server_completer},
+                   "unignore": [{'argument': 'nodes', 'metavar': 'NODE', 'nargs': '+',
+                                 'completer': server_name_completer},
                                 functools.partial(manager_locker_ignore, False)],
                    'show': [{'argument': 'node', 'nargs': '+', 'completer': server_name_completer},
                             manager_locker_show],
@@ -753,7 +759,8 @@ nested_dict = {
         'list': [
             {'argument': '--version', 'action': 'store', 'type': int,
              'completer': orch_ver_completer},
-            {'argument': '--detail', 'action': 'store_true'},
+            [{'argument': '--detail', 'action': 'store_true'},
+             {'argument': '--schema', 'action': 'store_true'}],
             [{'argument': '--like'},
              {'argument': '--id', 'dest': 'ident', 'completer': orch_completer},
              {'argument': '--name', 'completer': orch_name_completer}],
@@ -772,7 +779,7 @@ nested_dict = {
             orch_load],
         'run': [
             {'argument': 'orchestration_id', 'completer': orch_completer},
-            {'argument': '--target', 'metavar': 'TARGET=VALUE', 'action': DictAction, 'nargs': "+", 'dest': 'hosts',
+            {'argument': 'target', 'metavar': 'TARGET=VALUE', 'action': DictAction, 'nargs': "+",
              'completer': merge_completers([server_name_completer, granule_completer]),
              'help': "Run the orch agains the specified target. If no target specified, hosts will be added to "
                      "'all' target. Example: --target node1 node2 backend=node2,node3 "},
