@@ -3,10 +3,8 @@ import multiprocessing as mp
 import os
 import signal
 import sys
-import threading
 
 from dataclasses import dataclass
-from sqlalchemy.orm import sessionmaker
 
 
 @dataclass
@@ -92,4 +90,4 @@ class Process:
         raise NotImplemented
 
     def start(self):
-        self.process.start()
\ No newline at end of file
+        self.process.start()
